# Frameless Dialog

A frameless QDialog widget.

## Description

This frameless QDialog widget can be used as a direct replacement for the standard QDialog within the PyQt6 library.

## Getting Started

### Dependencies

* PyQt6
* Windows

### Installing

* pip install frameless_dialog


## Authors

Philip Messner [rxphil35@gmail.com](mailto:rxphil35@gmail.com)


## Version History

* 0.1
    * Initial Release

## License

This project is licensed under the MIT License - see the LICENSE.txt file for details
